/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __TIZEN_APPFW_COMPONENT_MANAGER_DOC_H__
#define __TIZEN_APPFW_COMPONENT_MANAGER_DOC_H__

/**
 * @defgroup CAPI_COMPONENT_MANAGER_MODULE Component Manager
 * @ingroup CAPI_APPLICATION_FRAMEWORK
 * @brief The @ref CAPI_COMPONENT_MANAGER_MODULE API provides functions to get information about installed or running components and manage the components.
 *
 * @section CAPI_COMPONENT_MANAGER_MODULE_HEADER Required Header
 *   \#include <component_manager.h>
 *
 * @section CAPI_COMPONENT_MANAGER_MODULE_OVERVIEW Overview
 * The @ref CAPI_COMPONENT_MANAGER_MODULE API provides functions to retrieve components information and to manager components.
 * There are two iterator functions that retrieve components. One is component_manager_foreach_component_context(), which gets the information of running components, the other is component_manager_foreach_component_info(), which gets the information of installed components.
 * The registered callback function is called as much as components exist in the list. An application can get the component's properties such as a name, a type, an icon path in the callback function.
 * Resuming components or terminating background components are also supported to handle components.
 */

/**
 * @defgroup CAPI_COMPONENT_CONTEXT_MODULE Component Context
 * @ingroup CAPI_COMPONENT_MANAGER_MODULE
 * @brief The @ref CAPI_COMPONENT_CONTEXT_MODULE API contains functions for obtaining information about running components.
 *
 * @section CAPI_COMPONENT_CONTEXT_MODULE_HEADER Required Header
 *   \#include <component_manager.h>
 *
 * @section CAPI_COMPONENT_CONTEXT_MODULE_OVERVIEW Overview
 * @remarks The @ref CAPI_COMPONENT_CONTEXT_MODULE API provides information about running components.
 */

/**
 * @defgroup CAPI_COMPONENT_INFO_MODULE Component Information
 * @ingroup CAPI_COMPONENT_MANAGER_MODULE
 * @brief The @ref CAPI_COMPONENT_INFO_MODULE API contains functions for obtaining information about installed components.
 *
 * @section CAPI_COMPONENT_INFO_MODULE_HEADER Required Header
 *   \#include <component_manager.h>
 *
 * @section CAPI_COMPONENT_INFO_MODULE_OVERVIEW Overview
 * @remarks The @ref CAPI_COMPONENT_INFO_MODULE API provides two types of functionality:
 * - Provides installed component's information such as name, type, icon path.

 */

#endif /* __TIZEN_APPFW_COMPONENT_MANAGER_DOC_H__ */
