/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __TIZEN_APPFW_COMPONENT_INFO_INTERNAL_H
#define __TIZEN_APPFW_COMPONENT_INFO_INTERNAL_H

#include <component_manager.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @file component_info_internal.h
 */

/**
* @addtogroup CAPI_COMPONENT_INFO_MODULE
* @{
*/

/**
 * @brief Retrieves all running component context.
 * @since_tizen 5.5
 * @privlevel public
 * @privilege %http://tizen.org/privilege/packagemanager.info
 *
 * @param[in]   callback        The callback function to invoke
 * @param[in]   user_data       The user data to be passed from the callback function
 * @return      @c 0 on success,
 *              otherwise a negative error value
 * @retval #COMPONENT_MANAGER_ERROR_NONE Successful
 * @retval #COMPONENT_MANAGER_ERROR_PERMISSION_DENIED Permission denied
 * @retval #COMPONENT_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
 * @retval #COMPONENT_MANAGER_ERROR_NO_SUCH_COMPONENT No such component
 * @retval #COMPONENT_MANAGER_ERROR_OUT_OF_MEMORY Out of memory
 * @retval #COMPONENT_MANAGER_ERROR_IO_ERROR I/O error
 */
int component_info_foreach(component_manager_component_info_cb callback, void *user_data);

/**
* @}
*/

#ifdef __cplusplus
}
#endif

#endif /* __TIZEN_APPFW_COMPONENT_INFO_INTERNAL_H */
