/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#define _GNU_SOURCE
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include "component_manager.h"
#include "component_manager_private.h"
#include "component_context_internal.h"
#include "component_info_internal.h"

EXPORT_API int component_manager_foreach_component_context(
		component_manager_component_context_cb callback,
		void *user_data)
{
	int ret;

	if (!callback) {
		LOGE("Invalid parameter");
		return COMPONENT_MANAGER_ERROR_INVALID_PARAMETER;
	}

	ret = component_context_foreach(callback, user_data);
	if (ret != COMPONENT_MANAGER_ERROR_NONE)
		return ret;

	return COMPONENT_MANAGER_ERROR_NONE;
}

EXPORT_API int component_manager_foreach_component_info(
		component_manager_component_info_cb callback,
		void *user_data)
{
	int ret;

	if (!callback) {
		LOGE("Invalid parameter");
		return COMPONENT_MANAGER_ERROR_INVALID_PARAMETER;
	}

	ret = component_info_foreach(callback, user_data);
	if (ret != COMPONENT_MANAGER_ERROR_NONE)
		return ret;

	return COMPONENT_MANAGER_ERROR_NONE;
}

EXPORT_API int component_manager_get_component_context(const char *comp_id,
		component_context_h *handle)
{
	int ret;

	if (!comp_id || !handle) {
		LOGE("Invalid parameter");
		return COMPONENT_MANAGER_ERROR_INVALID_PARAMETER;
	}

	ret = component_context_create(comp_id, handle);
	if (ret != COMPONENT_MANAGER_ERROR_NONE)
		return ret;

	return COMPONENT_MANAGER_ERROR_NONE;
}

EXPORT_API int component_manager_get_component_info(const char *comp_id,
		component_info_h *handle)
{
	int ret;

	if (!comp_id || !handle) {
		LOGE("Invalid parameter");
		return COMPONENT_MANAGER_ERROR_INVALID_PARAMETER;
	}

	ret = component_info_create(comp_id, handle);
	if (ret != COMPONENT_MANAGER_ERROR_NONE)
		return ret;

	return COMPONENT_MANAGER_ERROR_NONE;
}

EXPORT_API int component_manager_is_running(const char *comp_id, bool *running)
{
	component_context_h handle = NULL;
	int ret;

	if (!comp_id || !running) {
		LOGE("Invalid parameter");
		return COMPONENT_MANAGER_ERROR_INVALID_PARAMETER;
	}

	ret = component_context_create(comp_id, &handle);
	if (ret != COMPONENT_MANAGER_ERROR_NONE) {
		if (ret == COMPONENT_MANAGER_ERROR_NO_SUCH_COMPONENT) {
			*running = false;
			return COMPONENT_MANAGER_ERROR_NONE;
		}

		return ret;
	}

	ret = component_context_is_running(handle, running);
	component_context_destroy(handle);
	if (ret != COMPONENT_MANAGER_ERROR_NONE)
		return ret;

	return COMPONENT_MANAGER_ERROR_NONE;
}

EXPORT_API int component_manager_resume_component(component_context_h handle)
{
	int ret;

	if (!handle) {
		LOGE("Invalid parameter");
		return COMPONENT_MANAGER_ERROR_INVALID_PARAMETER;
	}

	ret = component_context_resume(handle);
	if (ret != COMPONENT_MANAGER_ERROR_NONE)
		return ret;

	return COMPONENT_MANAGER_ERROR_NONE;
}

EXPORT_API int component_manager_terminate_bg_component(
		component_context_h handle)
{
	int ret;

	if (!handle) {
		LOGE("Invalid parameter");
		return COMPONENT_MANAGER_ERROR_INVALID_PARAMETER;
	}

	ret = component_context_terminate_bg_component(handle);
	if (ret != COMPONENT_MANAGER_ERROR_NONE)
		return ret;

	return COMPONENT_MANAGER_ERROR_NONE;
}

EXPORT_API int component_manager_pause_component(component_context_h handle)
{
	int ret;

	if (!handle) {
		LOGE("Invalid parameter");
		return COMPONENT_MANAGER_ERROR_INVALID_PARAMETER;
	}

	ret = component_context_pause(handle);
	if (ret != COMPONENT_MANAGER_ERROR_NONE)
		return ret;

	return COMPONENT_MANAGER_ERROR_NONE;
}

EXPORT_API int component_manager_terminate_component(component_context_h handle)
{
	int ret;

	if (!handle) {
		LOGE("Invalid parameter");
		return COMPONENT_MANAGER_ERROR_INVALID_PARAMETER;
	}

	ret = component_context_terminate(handle);
	if (ret != COMPONENT_MANAGER_ERROR_NONE)
		return ret;

	return COMPONENT_MANAGER_ERROR_NONE;
}
