/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef UNIT_TESTS_MOCK_MOCK_AUL_COMP_CONTEXT_H__
#define UNIT_TESTS_MOCK_MOCK_AUL_COMP_CONTEXT_H__

#include <stdbool.h>
#include <unistd.h>
#include <sys/types.h>

#include "mock.h"

#ifdef __cplusplus
extern "C" {
#endif

typedef void *aul_comp_context_h;

typedef bool (*aul_comp_context_cb)(aul_comp_context_h handle, void *user_data);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_foreach_comp_context, aul_comp_context_cb, void *);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_get_app_id, aul_comp_context_h, const char **);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_get_instance_id, aul_comp_context_h, const char **);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_get_comp_id, aul_comp_context_h, const char **);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_get_type, aul_comp_context_h, const char **);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_get_pid, aul_comp_context_h, pid_t *);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_get_status, aul_comp_context_h, int *);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_is_sub_comp, aul_comp_context_h, bool *);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_create, const char *, aul_comp_context_h *);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_usr_create, const char *, uid_t, aul_comp_context_h *);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_destroy, aul_comp_context_h);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_clone, aul_comp_context_h, aul_comp_context_h *);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_is_running, aul_comp_context_h, bool *);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_resume, aul_comp_context_h);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_pause, aul_comp_context_h);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_terminate_bg_comp, aul_comp_context_h);

DECLARE_FAKE_VALUE_FUNC(int, aul_comp_context_terminate, aul_comp_context_h);

#ifdef __cplusplus
}
#endif

#endif // UNIT_TESTS_MOCK_MOCK_AUL_COMP_CONTEXT_H__
