/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdlib.h>
#include <aul.h>
#include <gtest/gtest.h>

#include <iostream>
#include <memory>

#include "mock_aul_comp_context.h"
#include "component_manager_extension.h"

static int __fake_aul_comp_context_create(const char* comp_id,
    aul_comp_context_h* handle) {
  char* h = static_cast<char*>(malloc(sizeof(char)));
  if (!h)
    return AUL_R_ENOMEM;

  *handle = static_cast<aul_comp_context_h>(h);
  return AUL_R_OK;
}

static int __fake_aul_comp_context_destroy(aul_comp_context_h handle) {
  if (!handle)
    return AUL_R_EINVAL;

  std::free(static_cast<void*>(handle));
  return AUL_R_OK;
}

static int __fake_aul_comp_context_pause(aul_comp_context_h handle) {
  return AUL_R_OK;
}

static int __fake_aul_comp_context_terminate(aul_comp_context_h handle) {
  return AUL_R_OK;
}

class ComponentManagerExtensionTest : public testing::Test {
 public:
  virtual void SetUp() {
    aul_comp_context_create_fake.custom_fake =
      __fake_aul_comp_context_create;
    aul_comp_context_destroy_fake.custom_fake =
      __fake_aul_comp_context_destroy;
    aul_comp_context_pause_fake.custom_fake =
      __fake_aul_comp_context_pause;
    aul_comp_context_terminate_fake.custom_fake =
      __fake_aul_comp_context_terminate;

    component_manager_get_component_context("TestComponent", &handle_);
  }

  virtual void TearDown() {
    if (handle_ != nullptr) {
      component_context_destroy(handle_);
      handle_ = nullptr;
    }
  }

  component_context_h GetHandle() const {
    return handle_;
  }

  void SetHandle(component_context_h handle) {
    handle_ = handle;
  }

 private:
  component_context_h handle_ = nullptr;
};

TEST_F(ComponentManagerExtensionTest,
    component_manager_pause_component_Positive) {
  component_context_h handle = GetHandle();

  int ret = component_manager_pause_component(handle);
  EXPECT_EQ(ret, COMPONENT_MANAGER_ERROR_NONE);
}

TEST_F(ComponentManagerExtensionTest,
    component_manager_pause_component_Negative) {
  int ret = component_manager_pause_component(nullptr);
  EXPECT_EQ(ret, COMPONENT_MANAGER_ERROR_INVALID_PARAMETER);
}

TEST_F(ComponentManagerExtensionTest,
    component_manager_terminate_component_Positive) {
  component_context_h handle = GetHandle();

  int ret = component_manager_terminate_component(handle);
  EXPECT_EQ(ret, COMPONENT_MANAGER_ERROR_NONE);
}

TEST_F(ComponentManagerExtensionTest,
    component_manager_terminate_component_Negative) {
  int ret = component_manager_terminate_component(nullptr);
  EXPECT_EQ(ret, COMPONENT_MANAGER_ERROR_INVALID_PARAMETER);
}
